@@ -657,7 +657,8 @@ class BiCoN(object):
             if len(group_g) >= L_g:
                 g = nx.subgraph(G, group_g)
                 # we are taking only the biggest connected component
-                comp_big = max(nx.connected_component_subgraphs(g), key=len)
+                comp_big = g.subgraph(max(nx.connected_components(g), key=len))
+
                 # measure the degree of each node in it
                 dg = dict(nx.degree(comp_big))
                 # separate those with d == 1 as nodes that we can kick out potentially
@@ -681,7 +682,8 @@ class BiCoN(object):
 
                         nodes = list(set(nodes) - set(outsiders))
                         g = nx.subgraph(G, nodes)
-                        comp_big = max(nx.connected_component_subgraphs(g), key=len)
+                        comp_big = g.subgraph(max(nx.connected_components(g), key=len))
+
                         dg = dict(nx.degree(comp_big))
                         if d_cut == 1:
                             ones = [x for x in dg if (dg[x] == 1)]
